<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:d="http://datacite.org/schema/kernel-3"
                exclude-result-prefixes="d"
                xsi:schemaLocation="http://datacite.org/schema/kernel-3 http://schema.datacite.org/meta/kernel-3/metadata.xsd">

    <xsl:output method="text" indent="no" omit-xml-declaration="yes" encoding="utf-8"/>

    <xsl:strip-space elements="*"/>


    <!-- DOI xml root = resource -->
    <xsl:template match="d:resource">
        <xsl:call-template name="row">
            <xsl:with-param name="key"># Generated by doi2csv.xsl</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
        <xsl:apply-templates select="./*"/>
    </xsl:template>


    <!-- 1. Identifier -->
    <xsl:template match="d:identifier">
        <xsl:call-template name="row">
            <xsl:with-param name="key">identifier</xsl:with-param>
            <xsl:with-param name="attr">DOI</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 2. Creator(s) -->
    <xsl:template match="d:creators/d:creator">
        <xsl:call-template name="row">
            <xsl:with-param name="key">creatorName</xsl:with-param>
            <xsl:with-param name="value" select="d:creatorName/text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 3. Title(s) -->
    <xsl:template match="d:titles/d:title">
        <xsl:call-template name="row">
            <xsl:with-param name="key">title</xsl:with-param>
            <xsl:with-param name="attr" select="@titleType"/>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 4. Publisher -->
    <xsl:template match="d:publisher">
        <xsl:call-template name="row">
            <xsl:with-param name="key">publisher</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 5. PublicationYear -->
    <xsl:template match="d:publicationYear">
        <xsl:call-template name="row">
            <xsl:with-param name="key">publicationYear</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 6. Subject(s) -->
    <xsl:template match="d:subjects/d:subject">
        <xsl:call-template name="row">
            <xsl:with-param name="key">subject</xsl:with-param>
            <xsl:with-param name="attr" select="@subjectScheme"/>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 7. Contributor(s) -->
    <xsl:template match="d:contributors/d:contributor">
        <xsl:call-template name="row">
            <xsl:with-param name="key">contributorName</xsl:with-param>
            <xsl:with-param name="attr" select="@contributorType"/>
            <xsl:with-param name="value" select="d:contributorName/text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 8. Date(s) -->
    <xsl:template match="d:dates/d:date">
        <xsl:call-template name="row">
            <xsl:with-param name="key">date</xsl:with-param>
            <xsl:with-param name="attr" select="@dateType"/>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 9. Language -->
    <xsl:template match="d:language">
        <xsl:call-template name="row">
            <xsl:with-param name="key">language</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 10. Resource type -->
    <xsl:template match="d:resourceType">
        <xsl:call-template name="row">
            <xsl:with-param name="key">resourceType</xsl:with-param>
            <xsl:with-param name="attr" select="@resourceTypeGeneral"/>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 11. Alternate identifier(s) -->
    <xsl:template match="d:alternateIdentifiers/d:alternateIdentifier">
        <xsl:call-template name="row">
            <xsl:with-param name="key">alternateIdentifier</xsl:with-param>
            <xsl:with-param name="attr" select="@alternateIdentifierType"/>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 12. Related identifier(s) -->
    <xsl:template match="d:relatedIdentifiers/d:relatedIdentifier">
        <xsl:call-template name="row">
            <xsl:with-param name="key">relatedIdentifier</xsl:with-param>
            <xsl:with-param name="attr" select="@relationType"/>
            <xsl:with-param name="attr2" select="@relatedIdentifierType"/>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 13. Size -->
    <xsl:template match="d:sizes/d:size">
        <xsl:call-template name="row">
            <xsl:with-param name="key">size</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 14. Format(s) -->
    <xsl:template match="d:formats/d:format">
        <xsl:call-template name="row">
            <xsl:with-param name="key">format</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 15. Version -->
    <xsl:template match="d:version">
        <xsl:call-template name="row">
            <xsl:with-param name="key">version</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 16. Rights -->
    <xsl:template match="d:rightsList/d:rights">
        <xsl:call-template name="pair">
            <xsl:with-param name="key">rights</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
        <xsl:if test="@rightsURI">
            <!-- optional rightsURI attribute -->
            <xsl:text>;</xsl:text>
            <xsl:call-template name="pair">
                <xsl:with-param name="key">rightsURI</xsl:with-param>
                <xsl:with-param name="value" select="@rightsURI"/>
            </xsl:call-template>
        </xsl:if>
        <xsl:text>&#10;</xsl:text>
    </xsl:template>


    <!-- 17. Description(s) -->
    <xsl:template match="d:descriptions/d:description">
        <xsl:call-template name="row">
            <xsl:with-param name="key">description</xsl:with-param>
            <xsl:with-param name="attr" select="@descriptionType"/>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>


    <!-- 18. GeoLocation(s) -->
    <xsl:template match="d:geoLocations/d:geoLocation/d:geoLocationPoint">
        <xsl:call-template name="row">
            <xsl:with-param name="key">geoLocationPoint</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="d:geoLocations/d:geoLocation/d:geoLocationBox">
        <xsl:call-template name="row">
            <xsl:with-param name="key">geoLocationBox</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="d:geoLocations/d:geoLocation/d:geoLocationPlace">
        <xsl:call-template name="row">
            <xsl:with-param name="key">geoLocationPlace</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
    </xsl:template>

    <!-- override the built-in template rule for text nodes -->
    <xsl:template match="text()"/>




    <xsl:template name="row">
        <xsl:param name="key"/>
        <xsl:param name="attr" select="''"/>
        <xsl:param name="attr2" select="''"/>
        <xsl:param name="value" select="''"/>

        <xsl:call-template name="pair">
            <xsl:with-param name="key" select="$key"/>
            <xsl:with-param name="attr" select="$attr"/>
            <xsl:with-param name="attr2" select="$attr2"/>
            <xsl:with-param name="value" select="$value"/>
        </xsl:call-template>

        <xsl:text>&#10;</xsl:text>
    </xsl:template>

    <xsl:template name="pair">
        <xsl:param name="key"/>
        <xsl:param name="attr" select="''"/>
        <xsl:param name="attr2" select="''"/>
        <xsl:param name="value" select="''"/>

        <xsl:value-of select="$key"/>
        <xsl:if test="string-length($attr) != 0">
            <xsl:text>:</xsl:text>
            <xsl:value-of select="$attr"/>
            <xsl:if test="string-length($attr2) != 0">
                <xsl:text>:</xsl:text>
                <xsl:value-of select="$attr2"/>
            </xsl:if>
        </xsl:if>
        <xsl:text>;</xsl:text>

        <xsl:if test="string-length($value) != 0">
            <!-- replace ';' by ',' -->
            <xsl:variable name="encValue" select="translate($value, ';', ',')"/>
            <xsl:choose>
                <xsl:when test="contains($encValue, '&#10;')">
                    <xsl:text>"</xsl:text>
                    <xsl:call-template name="escapeQuote">
                        <xsl:with-param name="pText" select="$encValue"/>
                    </xsl:call-template>
                    <xsl:text>"</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$encValue"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>




    <xsl:template name="escapeQuote">
        <xsl:param name="pText" select="."/>

        <xsl:if test="string-length($pText) >0">
            <xsl:value-of select="substring-before(concat($pText, '&quot;'), '&quot;')"/>

            <xsl:if test="contains($pText, '&quot;')">
                <xsl:text>""</xsl:text>

                <xsl:call-template name="escapeQuote">
                    <xsl:with-param name="pText" select="substring-after($pText, '&quot;')"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>
