<?xml version="1.0" encoding="utf-8"?>
<!--
   XSLT: this converts a complete CSW GetRecords response (XML) to a CSV (txt) file
-->
<xsl:stylesheet version="1.0"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:gco="http://www.isotc211.org/2005/gco"
                xmlns:gmd="http://www.isotc211.org/2005/gmd"
                xmlns:gml="http://www.opengis.net/gml"
                xmlns:gmx="http://www.isotc211.org/2005/gmx"
                exclude-result-prefixes="gmd gco gml gmx"
                xmlns:exsl="http://exslt.org/common"
                extension-element-prefixes="exsl">

    <xsl:output method="text" indent="no" omit-xml-declaration="yes" encoding="utf-8"/>

    <xsl:strip-space elements="*"/>

    <xsl:param name="DOI_PREFIX">10.5072</xsl:param>
    <xsl:param name="DOI_SUFFIX_START">UNDEFINED</xsl:param>

    <xsl:param name="USE_END_DATE" select="''"/>


    <!-- DOI metadata template -->
    <xsl:template match="/">
        <xsl:call-template name="row">
            <xsl:with-param name="key"># Generated by csw2txt.xsl</xsl:with-param>
            <xsl:with-param name="value" select="text()"/>
        </xsl:call-template>
        <xsl:apply-templates select="//gmd:MD_Metadata"/>
    </xsl:template>




    <xsl:template match="gmd:MD_Metadata">
        <xsl:call-template name="row">
            <xsl:with-param name="key"># BEGIN</xsl:with-param>
        </xsl:call-template>

        <xsl:if test="gmd:fileIdentifier/gco:CharacterString">
            <xsl:call-template name="row">
                <xsl:with-param name="key"># ID</xsl:with-param>
                <xsl:with-param name="value" select="gmd:fileIdentifier/gco:CharacterString/text()"/>
            </xsl:call-template>
        </xsl:if>

        <!--
            1. Identifier: DOI (obligatoire) sous la forme 'préfixe/suffixe'
        -->
        <xsl:call-template name="identifier">
            <xsl:with-param name="value">
                <xsl:choose>
                    <!-- AMMA-CATCH: dataset name -->
                    <xsl:when test="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:citation/gmd:CI_Citation/gmd:identifier/gmd:MD_Identifier/gmd:code/gco:CharacterString">
                        <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:citation/gmd:CI_Citation/gmd:identifier/gmd:MD_Identifier/gmd:code/gco:CharacterString/text()" />
                    </xsl:when>
                    <!-- OHMCV: HyMex ID -->
                    <xsl:when test="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:citation/gmd:CI_Citation/gmd:identifier/gmd:RS_Identifier/gmd:code/gco:CharacterString">
                        <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:citation/gmd:CI_Citation/gmd:identifier/gmd:RS_Identifier/gmd:code/gco:CharacterString/text()" />
                    </xsl:when>
                    <xsl:when test="gmd:fileIdentifier/gco:CharacterString">
                        <xsl:value-of select="gmd:fileIdentifier/gco:CharacterString/text()" />
                    </xsl:when>
                    <xsl:otherwise></xsl:otherwise>
                </xsl:choose>
            </xsl:with-param>
        </xsl:call-template>

        <xsl:apply-templates select="gmd:identificationInfo/gmd:MD_DataIdentification" mode="title"/>
        <xsl:apply-templates select="gmd:identificationInfo/gmd:MD_DataIdentification" mode="publicationYear"/>
        <xsl:apply-templates select="gmd:identificationInfo/gmd:MD_DataIdentification" mode="subjects"/>

        <xsl:apply-templates select="." mode="contributors"/>

        <xsl:apply-templates select="gmd:identificationInfo/gmd:MD_DataIdentification" mode="dates"/>
        <xsl:apply-templates select="gmd:identificationInfo/gmd:MD_DataIdentification" mode="descriptions"/>
        <xsl:apply-templates select="gmd:identificationInfo/gmd:MD_DataIdentification" mode="geoLocations"/>

        <xsl:call-template name="row">
            <xsl:with-param name="key"># END</xsl:with-param>
        </xsl:call-template>
    </xsl:template>




    <xsl:template match="gmd:identificationInfo/gmd:MD_DataIdentification" mode="title">
        <xsl:if test="gmd:citation/gmd:CI_Citation/gmd:title/gco:CharacterString">
            <!--
                3. Title: Titre du service / jeu de données
            -->
            <xsl:call-template name="row">
                <xsl:with-param name="key">title</xsl:with-param>
                <xsl:with-param name="value" select="gmd:citation/gmd:CI_Citation/gmd:title/gco:CharacterString/text()"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>


    <xsl:template match="gmd:identificationInfo/gmd:MD_DataIdentification" mode="publicationYear">
        <xsl:if test="gmd:extent/gmd:EX_Extent/gmd:temporalElement/gmd:EX_TemporalExtent/gmd:extent/gml:TimePeriod/gml:beginPosition">
            <!--
                5. PublicationYear: Date de première mise à disposition du service / jeu de données au public
            -->
            <xsl:call-template name="row">
                <xsl:with-param name="key">publicationYear</xsl:with-param>
                <xsl:with-param name="value" select="substring(gmd:extent/gmd:EX_Extent/gmd:temporalElement/gmd:EX_TemporalExtent/gmd:extent/gml:TimePeriod/gml:beginPosition/text(), 1, 4)"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>


    <xsl:template match="gmd:identificationInfo/gmd:MD_DataIdentification" mode="subjects">
        <xsl:if test="gmd:descriptiveKeywords">
            <!--
                6. Subject: Liste ordonnée de mots-clés
                    1/ Sujet d'observation
                        par exemple: pour AMMA-CATCH:
                            <subject>Tropical climate</subject>
            -->
            <xsl:for-each select="gmd:descriptiveKeywords/gmd:MD_Keywords[not(gmd:type)]/gmd:keyword">
                <xsl:call-template name="row">
                    <xsl:with-param name="key">subject</xsl:with-param>
                    <xsl:with-param name="attr">main</xsl:with-param>
                    <xsl:with-param name="value" select="./gco:CharacterString/text()"/>
                </xsl:call-template>
            </xsl:for-each>
            <xsl:for-each select="gmd:descriptiveKeywords/gmd:MD_Keywords[gmd:type/gmd:MD_KeywordTypeCode/@codeListValue='VariablesCategory']/gmd:keyword">
                <xsl:call-template name="row">
                    <xsl:with-param name="key">subject</xsl:with-param>
                    <xsl:with-param name="attr">main</xsl:with-param>
                    <xsl:with-param name="value" select="./gmx:Anchor/text()"/>
                </xsl:call-template>
            </xsl:for-each>

            <!-- OHMCV -->
            <xsl:for-each select="gmd:descriptiveKeywords/gmd:MD_Keywords[gmd:type/gmd:MD_KeywordTypeCode/@codeListValue='theme']/gmd:keyword">
                <!-- ignore fake OSUG keyword -->
                <xsl:if test="not(starts-with(./gco:CharacterString/text(),'OSUG'))">
                    <xsl:call-template name="row">
                        <xsl:with-param name="key">subject</xsl:with-param>
                        <xsl:with-param name="attr">main</xsl:with-param>
                        <xsl:with-param name="value" select="./gco:CharacterString/text()"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:for-each>

            <!--
                6. Subject: Liste ordonnée de mots-clés
                    2/ Variables observées / mots clés du domaine appropriés
                        par exemple: pour AMMA-CATCH:
                            <subject>Discharge</subject>
            -->
            <xsl:for-each select="gmd:descriptiveKeywords/gmd:MD_Keywords[gmd:type/gmd:MD_KeywordTypeCode/@codeListValue='Variables']/gmd:keyword">
                <xsl:call-template name="row">
                    <xsl:with-param name="key">subject</xsl:with-param>
                    <xsl:with-param name="attr">var</xsl:with-param>
                    <xsl:with-param name="value" select="./gmx:Anchor/text()"/>
                </xsl:call-template>
            </xsl:for-each>
        </xsl:if>
    </xsl:template>


    <xsl:template match="gmd:MD_Metadata" mode="contributors">
        <!--
            7. Contributor: Liste des personnes / institutions associées au jeu de données / service d'observation
        -->
        <xsl:if test="gmd:contact">
            <xsl:for-each select="gmd:contact/gmd:CI_ResponsibleParty[gmd:role/gmd:CI_RoleCode/@codeListValue='pointOfContact']">
                <xsl:call-template name="row">
                    <xsl:with-param name="key">contributorName</xsl:with-param>
                    <xsl:with-param name="attr">DataManager</xsl:with-param>
                    <xsl:with-param name="value">
                        <xsl:value-of select="gmd:individualName/gco:CharacterString/text()"/>
                    </xsl:with-param>
                    <xsl:with-param name="key2">affiliation</xsl:with-param>
                    <xsl:with-param name="value2">
                        <xsl:value-of select="gmd:organisationName/gco:CharacterString/text()"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:for-each>

            <xsl:for-each select="gmd:contact/gmd:CI_ResponsibleParty[gmd:role/gmd:CI_RoleCode/@codeListValue='principalInvestigator']">
                <xsl:call-template name="row">
                    <xsl:with-param name="key">contributorName</xsl:with-param>
                    <xsl:with-param name="attr">WorkPackageLeader</xsl:with-param>
                    <xsl:with-param name="value">
                        <xsl:value-of select="gmd:individualName/gco:CharacterString/text()"/>
                    </xsl:with-param>
                    <xsl:with-param name="key2">affiliation</xsl:with-param>
                    <xsl:with-param name="value2">
                        <xsl:value-of select="gmd:organisationName/gco:CharacterString/text()"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:for-each>
        </xsl:if>

        <!-- OHMCV: PI dans pointOfContact -->
        <xsl:if test="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:pointOfContact">
            <xsl:for-each select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:pointOfContact/gmd:CI_ResponsibleParty[gmd:role/gmd:CI_RoleCode/@codeListValue='principalInvestigator']">
                <xsl:call-template name="row">
                    <xsl:with-param name="key">contributorName</xsl:with-param>
                    <xsl:with-param name="attr">WorkPackageLeader</xsl:with-param>
                    <xsl:with-param name="value">
                        <xsl:value-of select="gmd:individualName/gco:CharacterString/text()"/>
                    </xsl:with-param>
                    <xsl:with-param name="key2">affiliation</xsl:with-param>
                    <xsl:with-param name="value2">
                        <xsl:value-of select="gmd:organisationName/gco:CharacterString/text()"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:for-each>
        </xsl:if>
    </xsl:template>


    <xsl:template match="gmd:identificationInfo/gmd:MD_DataIdentification" mode="dates">
        <xsl:if test="gmd:extent/gmd:EX_Extent/gmd:temporalElement/gmd:EX_TemporalExtent/gmd:extent/gml:TimePeriod/gml:beginPosition">
            <!--
                8. Date: Donner la date de début (et de fin) de collecte des données [dateType=Collected]
            -->
            <xsl:call-template name="row">
                <xsl:with-param name="key">date</xsl:with-param>
                <xsl:with-param name="attr">Collected</xsl:with-param>
                <xsl:with-param name="value">
                    <xsl:value-of select="substring(gmd:extent/gmd:EX_Extent/gmd:temporalElement/gmd:EX_TemporalExtent/gmd:extent/gml:TimePeriod/gml:beginPosition/text(), 1, 10)"/>
                    <xsl:text>/</xsl:text>
                    <xsl:if test="$USE_END_DATE = 'true'">
                        <xsl:value-of select="substring(gmd:extent/gmd:EX_Extent/gmd:temporalElement/gmd:EX_TemporalExtent/gmd:extent/gml:TimePeriod/gml:endPosition/text(), 1, 10)"/>
                    </xsl:if>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:if>

    </xsl:template>


    <xsl:template match="gmd:identificationInfo/gmd:MD_DataIdentification" mode="descriptions">
        <!--
            17. Description: Donner une description textuelle du jeu de données / service (abstract)
        -->
        <xsl:if test="gmd:purpose">
            <xsl:call-template name="row">
                <xsl:with-param name="key">description</xsl:with-param>
                <xsl:with-param name="attr">Abstract</xsl:with-param>
                <xsl:with-param name="value" select="gmd:purpose/gco:CharacterString/text()"/>
            </xsl:call-template>
        </xsl:if>

        <xsl:if test="gmd:abstract">
            <xsl:call-template name="row">
                <xsl:with-param name="key">description</xsl:with-param>
                <xsl:with-param name="attr">SeriesInformation</xsl:with-param>
                <xsl:with-param name="value" select="gmd:abstract/gco:CharacterString/text()"/>
            </xsl:call-template>
        </xsl:if>

        <xsl:if test="gmd:citation/gmd:CI_Citation/gmd:otherCitationDetails">
            <xsl:call-template name="row">
                <xsl:with-param name="key">description</xsl:with-param>
                <xsl:with-param name="attr">Other</xsl:with-param>
                <xsl:with-param name="value">
                    <xsl:text>Reference publication: </xsl:text>
                    <xsl:value-of select="gmd:citation/gmd:CI_Citation/gmd:otherCitationDetails/gco:CharacterString/text()"/>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>


    <xsl:template match="gmd:identificationInfo/gmd:MD_DataIdentification" mode="geoLocations">
        <!--
        18. GeoLocation: Indiquer la zone géographique où ont été collectées les données (optionnel)
        -->
        <xsl:variable name="place" select="gmd:extent/gmd:EX_Extent/gmd:geographicElement/gmd:EX_GeographicDescription"/>
        <xsl:if test="$place">
            <xsl:variable name="tokens">
                <xsl:call-template name="split">
                    <xsl:with-param name="string" select="$place/gmd:geographicIdentifier/gmd:MD_Identifier/gmd:code/gco:CharacterString/text()"/>
                    <xsl:with-param name="pattern" select="':'" />
                </xsl:call-template>
            </xsl:variable>
            <xsl:variable name="nodes" select="exsl:node-set($tokens)/token"/>

            <xsl:if test="$nodes[2]">
                <xsl:call-template name="row">
                    <xsl:with-param name="key">geoLocationPlace</xsl:with-param>
                    <xsl:with-param name="value" select="$nodes[2]/text()"/>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$nodes[3]">
                <xsl:call-template name="row">
                    <xsl:with-param name="key">geoLocationPlace</xsl:with-param>
                    <xsl:with-param name="value" select="$nodes[3]/text()"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:if>

        <!-- OHMCV -->
        <xsl:if test="gmd:descriptiveKeywords">
            <!-- OHMCV -->
            <xsl:for-each select="gmd:descriptiveKeywords/gmd:MD_Keywords[gmd:type/gmd:MD_KeywordTypeCode/@codeListValue='place']/gmd:keyword">
                <xsl:variable name="name" select="./gco:CharacterString/text()"/>
                <xsl:if test="not(starts-with($name,'Disdrometer') or starts-with($name,'Kriging'))">
                    <xsl:call-template name="row">
                        <xsl:with-param name="key">geoLocationPlace</xsl:with-param>
                        <xsl:with-param name="value" select="./gco:CharacterString/text()"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:for-each>
        </xsl:if>

        <xsl:variable name="box" select="gmd:extent/gmd:EX_Extent/gmd:geographicElement/gmd:EX_GeographicBoundingBox"/>
        <xsl:if test="$box">
            <xsl:call-template name="row">
                <xsl:with-param name="key">geoLocationBox</xsl:with-param>
                <xsl:with-param name="value">
                    <xsl:value-of select="$box/gmd:westBoundLongitude/gco:Decimal/text()"/>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="$box/gmd:southBoundLatitude/gco:Decimal/text()"/>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="$box/gmd:eastBoundLongitude/gco:Decimal/text()"/>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="$box/gmd:northBoundLatitude/gco:Decimal/text()"/>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>




    <xsl:template name="split">
        <xsl:param name="string" select="''" />
        <xsl:param name="pattern" select="' '" />
        <xsl:choose>
            <xsl:when test="not($string)" />
            <xsl:when test="not($pattern)">
                <xsl:call-template name="_split-characters">
                    <xsl:with-param name="string" select="$string" />
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="_split-pattern">
                    <xsl:with-param name="string" select="$string" />
                    <xsl:with-param name="pattern" select="$pattern" />
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="_split-characters">
        <xsl:param name="string" />
        <xsl:if test="$string">
            <token>
                <xsl:value-of select="substring($string, 1, 1)" />
            </token>
            <xsl:call-template name="_split-characters">
                <xsl:with-param name="string" select="substring($string, 2)" />
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="_split-pattern">
        <xsl:param name="string" />
        <xsl:param name="pattern" />
        <xsl:choose>
            <xsl:when test="contains($string, $pattern)">
                <xsl:if test="not(starts-with($string, $pattern))">
                    <token>
                        <xsl:value-of select="substring-before($string, $pattern)" />
                    </token>
                </xsl:if>
                <xsl:call-template name="_split-pattern">
                    <xsl:with-param name="string" select="substring-after($string, $pattern)" />
                    <xsl:with-param name="pattern" select="$pattern" />
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <token>
                    <xsl:value-of select="$string" />
                </token>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>




    <xsl:template name="identifier">
        <xsl:param name="value"/>
        <xsl:if test="string-length($value) != 0">
            <xsl:call-template name="row">
                <xsl:with-param name="key">identifier</xsl:with-param>
                <xsl:with-param name="attr">DOI</xsl:with-param>
                <xsl:with-param name="value">
                    <xsl:value-of select="$DOI_PREFIX"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$DOI_SUFFIX_START"/>
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$value"/>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>




    <xsl:template name="row">
        <xsl:param name="key"/>
        <xsl:param name="attr" select="''"/>
        <xsl:param name="attr2" select="''"/>
        <xsl:param name="value" select="''"/>
        <xsl:param name="key2" select="''"/>
        <xsl:param name="value2" select="''"/>

        <xsl:value-of select="$key"/>
        <xsl:if test="string-length($attr) != 0">
            <xsl:text>:</xsl:text>
            <xsl:value-of select="$attr"/>
            <xsl:if test="string-length($attr2) != 0">
                <xsl:text>:</xsl:text>
                <xsl:value-of select="$attr2"/>
            </xsl:if>
        </xsl:if>
        <xsl:text>;</xsl:text>

        <xsl:if test="string-length($value) != 0">
            <!-- replace ';' by ',' -->
            <xsl:variable name="encValue" select="translate($value, ';', ',')"/>
            <xsl:choose>
                <xsl:when test="contains($encValue, '&#10;')">
                    <xsl:text>"</xsl:text>
                    <xsl:call-template name="escapeQuote">
                        <xsl:with-param name="pText" select="$encValue"/>
                    </xsl:call-template>
                    <xsl:text>"</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$encValue"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>

        <xsl:if test="string-length($key2) != 0 and string-length($value2) != 0">
            <xsl:text>;</xsl:text>
            <xsl:value-of select="$key2"/>
            <xsl:text>;</xsl:text>
            <!-- replace ';' by ',' -->
            <xsl:variable name="encValue" select="translate($value2, ';', ',')"/>
            <xsl:value-of select="$encValue"/>
        </xsl:if>

        <xsl:text>&#10;</xsl:text>
    </xsl:template>




    <xsl:template name="escapeQuote">
        <xsl:param name="pText" select="."/>

        <xsl:if test="string-length($pText) != 0">
            <xsl:value-of select="substring-before(concat($pText, '&quot;'), '&quot;')"/>

            <xsl:if test="contains($pText, '&quot;')">
                <xsl:text>""</xsl:text>

                <xsl:call-template name="escapeQuote">
                    <xsl:with-param name="pText" select="substring-after($pText, '&quot;')"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>
