/*******************************************************************************
 * OSUG-DOI project ( http://doi.osug.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi;

import com.opencsv.CSVReader;
import com.opencsv.CSVWriter;
import fr.osug.util.FileUtils;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FilenameFilter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;
import java.nio.charset.StandardCharsets;
import java.util.Arrays;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 * @author bourgesl
 */
public final class CsvUtil {

    private final static Logger logger = LoggerFactory.getLogger(CsvUtil.class.getName());

    private static boolean FAIL_ON_OVERWRITE = true;

    private CsvUtil() {
        // forbidden
    }

    public static CsvData read(final File csvFile) throws IOException {
        final CSVReader reader = new CSVReader(getTextReader(csvFile), Const.SEPARATOR);
        return new CsvData(csvFile.getAbsolutePath(), reader.readAll());
    }

    public static void write(final CsvData data, final File csvFile) throws IOException {
        if (!data.isEmpty()) {
            logger.info("Writing: {}", csvFile.getAbsolutePath());
            write(data, new FileOutputStream(csvFile));
        }
    }

    public static void write(final CsvData data, final OutputStream out) throws IOException {
        final CSVWriter writer = new CSVWriter(getTextWriter(out), Const.SEPARATOR);
        try {
            writer.writeAll(data.getRows(), false);
        } finally {
            writer.close();
        }
    }

    public static Reader getTextReader(final File file) throws IOException {
        return new InputStreamReader(new FileInputStream(file), StandardCharsets.UTF_8);
    }

    public static Writer getTextWriter(final File file) throws IOException {
        return getTextWriter(new FileOutputStream(file));
    }

    public static Writer getTextWriter(final OutputStream out) throws IOException {
        return new OutputStreamWriter(out, StandardCharsets.UTF_8);
    }

    public static File[] findCSVFiles(final String dirPath) throws IOException {
        final File inputDir = FileUtils.getRequiredDirectory(dirPath).getCanonicalFile();
        // find CSV files:
        return CsvUtil.getSortedFiles(inputDir, ".*\\.csv");
    }

    public static File[] getSortedFiles(final File directory, final String regexp) {
        final File[] dataFiles = directory.listFiles(new FilenameFilter() {
            @Override
            public boolean accept(final File dir, final String name) {
                return name.matches(regexp);
            }
        });

        // Sort file names:
        Arrays.sort(dataFiles);

        return dataFiles;
    }
}
