/*******************************************************************************
 * OSUG-DOI project ( http://doi.osug.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi;

import fr.osug.doi.service.DoiService;
import fr.osug.xml.XmlFactory;
import fr.osug.xml.validator.XmlValidatorFactory;
import java.util.Arrays;
import javax.annotation.PostConstruct;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Configuration;
import org.springframework.transaction.annotation.EnableTransactionManagement;

/**
 *
 * @author bourgesl
 */
@Configuration
@ConfigurationProperties(prefix = "osug.doi")
@EnableTransactionManagement
public class DOIConfig {

    private final static Logger logger = LoggerFactory.getLogger(DOIConfig.class.getName());

    /* debug flag */
    private boolean debug = false;

    @Autowired
    private ApplicationContext appCtx;

    @Autowired
    private XmlFactory xmlFactory;
    @Autowired
    private XmlValidatorFactory xmlValidatorFactory;

    @Autowired
    private DoiService doiService;
    
    /** DOI Prefix (registered in datacite) */
    private String prefix;

    /** DOI Domain (registered in datacite) */
    private String domain;

    @PostConstruct
    public void initialize() {
        this.debug = Arrays.asList(appCtx.getEnvironment().getActiveProfiles()).contains("debug");

        logger.info("debug mode: {}", debug);
        logger.info("doi prefix: {}", prefix);
        logger.info("doi domain: {}", domain);
    }

    public boolean isDebug() {
        return debug;
    }

    public ApplicationContext getAppCtx() {
        return appCtx;
    }

    public XmlFactory getXmlFactory() {
        return xmlFactory;
    }

    public XmlValidatorFactory getXmlValidatorFactory() {
        return xmlValidatorFactory;
    }

    public DoiService getDoiService() {
        return doiService;
    }

    public String getPrefix() {
        return prefix;
    }

    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }

    public String getDomain() {
        return domain;
    }

    public void setDomain(String domain) {
        this.domain = domain;
    }

}
