/*******************************************************************************
 * JMMC project ( http://www.jmmc.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi;

import fr.osug.doi.domain.NameEntry;
import fr.osug.util.StringBuilderWriter;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

/**
 *
 * @author bourgesl
 */
public final class PipelineGlobalData {

    private final static Set<String> NO_REFS = Collections.emptySet();

    private static final int BUFFER_SIZE = 4 * 1024;

    /* members */
    /** temporary StringBuilder to hold xml document */
    final StringBuilder buffer = new StringBuilder(BUFFER_SIZE);
    /** temporary StringBuilderWriter to hold doi document */
    final StringBuilderWriter doiDoc = new StringBuilderWriter(BUFFER_SIZE);
    // References:
    private final Map<String, Set<String>> doiRefs = new LinkedHashMap<String, Set<String>>();
    /* doi data (insertion order) */
    private final Map<String, PipelineDoiData> datas = new LinkedHashMap<String, PipelineDoiData>();
    // Name references:
    private final TreeSet<NameEntry> nameRefs = new TreeSet<NameEntry>(NameEntry.COMPARATOR);

    public Map<String, PipelineDoiData> getDoiDatas() {
        return datas;
    }

    PipelineDoiData newDoiData(final String doiId, final String doiSuffix, final String title) {
        PipelineDoiData doiData = getDoiData(doiId);
        // ensure unicity:
        if (doiData != null) {
            doiData.addError("Duplicate detected for DOI: " + doiSuffix);
            // ignore later
            doiData = null;
        } else {
            doiData = new PipelineDoiData(doiId, doiSuffix, title);
            datas.put(doiId, doiData);
        }
        return doiData;
    }

    PipelineDoiData getDoiData(final String doiId) {
        return datas.get(doiId);
    }

    void addRefs(final String doiId, final Set<String> refs) {
        doiRefs.put(doiId, (refs != null) ? refs : NO_REFS);
    }

    boolean hasDoiId(final String doiId) {
        return doiRefs.get(doiId) != null;
    }

    Set<String> getDoiIds() {
        return doiRefs.keySet();
    }

    Set<String> getDoiRefs(final String id) {
        return doiRefs.get(id);
    }

    void addNameRef(final String[] cols) {
        final String name = cols[1];
        final NameEntry entry;
        if (cols.length == 2) {
            entry = new NameEntry(name);
        } else {
            final Map<String, String> attributes = new HashMap<String, String>();
            for (int i = 2; i < cols.length; i += 2) {
                attributes.put(cols[i], cols[i + 1]);
            }
            entry = new NameEntry(name, attributes);
        }
        nameRefs.add(entry);
    }

    public TreeSet<NameEntry> getNameRefs() {
        return nameRefs;
    }

}
