/*******************************************************************************
 * JMMC project ( http://www.jmmc.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi;

import fr.osug.doi.validation.WarningMessage;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 * @author bourgesl
 */
public final class PipelineDoiData {

    private final static Logger logger = LoggerFactory.getLogger(ProcessPipeline.class.getName());

    /* members */
    private final String doiId;
    private final String doiSuffix;
    /** doi title */
    private final String title;
    /** validation messages */
    private final List<WarningMessage> messages = new ArrayList<WarningMessage>();
    /** valid flag */
    private boolean valid;
    /** md5 metadata */
    private String metadataMd5;
    /** xml metadata */
    private File stagingFileDOI;
    /* external Landing page URL */
    private String landingPageUrl;

    PipelineDoiData(final String doiId, final String doiSuffix, final String title) {
        this.doiId = doiId;
        this.doiSuffix = doiSuffix;
        this.title = title;
        this.valid = true;
    }

    /**
     * Add the given message to the error messages
     * @param msg message to add
     */
    public void addError(final String msg) {
        setValid(false);
        logger.error(msg);
        messages.add(new WarningMessage(msg, WarningMessage.Level.Error));
    }

    /**
     * Add the given message to the warning messages
     * @param msg message to add
     */
    public void addWarning(final String msg) {
        setValid(false);
        logger.warn(msg);
        messages.add(new WarningMessage(msg, WarningMessage.Level.Warning));
    }

    /**
     * Add the given message to the information messages
     * @param msg message to add
     */
    public void addInfo(final String msg) {
        logger.info(msg);
        messages.add(new WarningMessage(msg, WarningMessage.Level.Information));
    }

    public String messagesToString() {
        final StringBuilder sb = new StringBuilder(1024);
        for (WarningMessage msg : messages) {
            sb.append(msg.getLevel()).append(" : ");
            sb.append(msg.getMessage()).append("\n");
        }
        return sb.toString();
    }

    public String getDoiId() {
        return doiId;
    }

    public String getDoiSuffix() {
        return doiSuffix;
    }

    public boolean isValid() {
        return valid;
    }

    void setValid(boolean valid) {
        this.valid = valid;
    }

    public String getTitle() {
        return title;
    }

    public String getMetadataMd5() {
        return metadataMd5;
    }

    public void setMetadataMd5(final String metadataMd5) {
        this.metadataMd5 = metadataMd5;
    }

    public File getStagingFileDOI() {
        return stagingFileDOI;
    }

    void setStagingFileDOI(final File stagingFileDOI) {
        this.stagingFileDOI = stagingFileDOI;
    }

    public String getLandingPageUrl() {
        return landingPageUrl;
    }

    public void setLandingPageUrl(final String landingPageUrl) {
        this.landingPageUrl = landingPageUrl;
    }

}
