/*******************************************************************************
 * OSUG-DOI project ( http://doi.osug.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi.domain;

import java.util.Date;
import java.util.Objects;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import org.springframework.data.domain.Persistable;

/**
 * A Doi in the staging phase
 */
@Entity
@Table(name = "doi_staging")
public class DoiStaging implements Persistable<Long> {

    private static final long serialVersionUID = 1L;

    @Id
    @SequenceGenerator(name = "doi_staging_id_seq", sequenceName = "doi_staging_id_seq", allocationSize = 10)
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "doi_staging_id_seq")
    private Long id;

    @OneToOne
    @JoinColumn(name = "doi_id")
    private Doi doi;

    @Column(name = "valid")
    private boolean valid;

    @Column(name = "metadata_md5")
    private String metadataMd5;

    @Column(name = "log")
    private String log;

    @Column(name = "landing_loc_url")
    private String landingLocUrl;

    @Column(name = "create_date")
    @Temporal(TemporalType.TIMESTAMP)
    private Date createDate;

    @Column(name = "update_date")
    @Temporal(TemporalType.TIMESTAMP)
    private Date updateDate;

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public boolean isNew() {
        return id == null;
    }

    public Doi getDoi() {
        return doi;
    }

    public void setDoi(Doi doi) {
        this.doi = doi;
    }

    public boolean isValid() {
        return valid;
    }

    public void setValid(boolean valid) {
        this.valid = valid;
    }

    public String getMetadataMd5() {
        return metadataMd5;
    }

    public void setMetadataMd5(String metadataMd5) {
        this.metadataMd5 = metadataMd5;
    }

    public String getLog() {
        return log;
    }

    public void setLog(String log) {
        this.log = log;
    }

    public String getLandingLocUrl() {
        return landingLocUrl;
    }

    public void setLandingLocUrl(String landingLocUrl) {
        this.landingLocUrl = landingLocUrl;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DoiStaging doi = (DoiStaging) o;
        if (doi.getId() == null || getId() == null) {
            return false;
        }
        return Objects.equals(getId(), doi.getId());
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(getId());
    }

    @Override
    public String toString() {
        return "DoiStaging{"
                + "id=" + id
                + ", doi=" + doi
                + ", valid='" + valid + "'"
                + ", metadataMd5='" + metadataMd5 + "'"
                + ", landingLocUrl='" + landingLocUrl + "'"
                + ", createDate='" + createDate + "'"
                + ", updateDate='" + updateDate + "'"
                + ", log=[\n" + log + "\n]"
                + '}';
    }
}
