/*******************************************************************************
 * JMMC project ( http://www.jmmc.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi.domain;

import java.util.Comparator;
import java.util.Map;
import java.util.Objects;

/**
 *
 * @author bourgesl
 */
public final class NameEntry {

    public static final Comparator<NameEntry> COMPARATOR = new Comparator<NameEntry>() {
        @Override
        public int compare(final NameEntry e1, final NameEntry e2) {
            int res = e1.getName().compareToIgnoreCase(e2.getName());
            if (res == 0) {
                final int len1 = (e1.getAttributes() != null) ? e1.getAttributes().size() : 0;
                final int len2 = (e2.getAttributes() != null) ? e2.getAttributes().size() : 0;
                res = Integer.compare(len1, len2);
            }
            return res;
        }
    };

    private final String name;
    private final Map<String, String> attributes;

    public NameEntry(String name) {
        this.name = name;
        this.attributes = null;
    }

    public NameEntry(String name, Map<String, String> attributes) {
        this.name = name;
        this.attributes = attributes;
    }

    public String getName() {
        return name;
    }

    public boolean hasAttributes() {
        return attributes != null;
    }

    public Map<String, String> getAttributes() {
        return attributes;
    }

    public String getAttribute(String key) {
        String val = attributes.get(key);
        return (val != null) ? val : "";
    }

    @Override
    public String toString() {
        return "{name=" + name + ", attributes=" + attributes + '}';
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 29 * hash + Objects.hashCode(this.name);
        hash = 29 * hash + Objects.hashCode(this.attributes);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final NameEntry other = (NameEntry) obj;
        if (!Objects.equals(this.name, other.getName())) {
            return false;
        }
        if (!Objects.equals(this.attributes, other.getAttributes())) {
            return false;
        }
        return true;
    }

}
