/*******************************************************************************
 * OSUG-DOI project ( http://doi.osug.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi.repository;

import fr.osug.doi.domain.Doi;
import fr.osug.doi.domain.DoiStaging;
import java.util.List;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * Spring Data JPA repository for the DoiStaging entity.
 */
@Repository
@Transactional
public interface DoiStagingRepository extends JpaRepository<DoiStaging, Long> {

    @Transactional(readOnly = true)
    DoiStaging findOneByDoi(Doi doi);

    @Transactional(readOnly = true)
    @Query("select ds from DoiStaging ds join ds.doi d join d.project p where (p.name = :projectName) order by d.identifier asc")
    List<DoiStaging> findByProject(@Param("projectName") String projectName);
    
    @Transactional(readOnly = true)
    @Query("select ds from DoiStaging ds join ds.doi d join d.project p where (p.name = :projectName) and ds.valid = false order by d.identifier asc")
    List<DoiStaging> findErrorByProject(@Param("projectName") String projectName);

    @Transactional(readOnly = true)
    @Query("select count(ds) from DoiStaging ds join ds.doi d join d.project p where (p.name = :projectName)")
    Long countByProject(@Param("projectName") String projectName);

}
