/*******************************************************************************
 * OSUG-DOI project ( http://doi.osug.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi.validation;

import fr.osug.doi.Const;
import fr.osug.doi.PipelineDoiData;
import fr.osug.doi.DoiCsvData;
import java.util.regex.Pattern;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 * @author bourgesl
 */
public class ValidationUtil {

    private final static Logger logger = LoggerFactory.getLogger(ValidationUtil.class.getName());
    /** regular expression used to match characters different than alpha/numeric/_/-/. (1..n) */
    private final static Pattern PATTERN_IDENTIFIER = Pattern.compile("[^a-zA-Z0-9\\-_\\.]");

    private ValidationUtil() {
    }

    public static boolean checkIdentifier(final String id, final Object data) {
        if (id == null || id.trim().isEmpty()) {
            // Missing identifier
            logger.error("Missing ''"
                    + Const.KEY_IDENTIFIER + "'' in dataset:\n{}", data);
            return false;
        }
        final String suffix = DoiCsvData.getDoiSuffix(id);
        if (suffix.trim().isEmpty()) {
            // Missing suffix
            logger.error("Missing suffix for ''"
                    + Const.KEY_IDENTIFIER + "'' in dataset:\n{}", data);
            return false;
        }
        return true;
    }

    public static void validateIdentifier(final String id, final PipelineDoiData pipeData) {
        // Check test prefix:
        if (!isTestPrefix(id)) {
            // identifier does not starts with the test prefix
            pipeData.addError("Invalid ''"
                    + Const.KEY_IDENTIFIER + "'': must be equals to the TEST prefix: " + Const.DOI_PREFIX_TEST);
        }
        final String suffix = DoiCsvData.getDoiSuffix(id);
        if (!checkIdentifier(suffix)) {
            // Invalid suffix
            pipeData.addError("Invalid suffix for ''" + Const.KEY_IDENTIFIER + "'' = '" + suffix + "'");
        }
    }
    
    public static boolean isTestPrefix(final String id) {
        return id.startsWith(Const.DOI_PREFIX_TEST);
    }

    /**
     * Check the DOI identifier against the regexp
     * @param value input value
     * @return true if the DOI identifier is valid
     */
    private static boolean checkIdentifier(final String value) {
        return !PATTERN_IDENTIFIER.matcher(value).matches();
    }
}
